# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/account/v1/account_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/account/v1/account_v1.proto\x12\x1astrmprivacy.api.account.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x17validate/validate.proto\"H\n\x18GetAccountDetailsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\"\xbb\x02\n\x19GetAccountDetailsResponse\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12/\n\x11max_input_streams\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02R\x0fmaxInputStreams\x12\x1b\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06handle\x12\'\n\x0csubscription\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0csubscription\x12\'\n\x0corganization\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0corganization\x12,\n\x0forganization_id\x18\x06 \x01(\tB\x03\xe0\x41\x02R\x0eorganizationId\x12-\n\x10internal_user_id\x18\x07 \x01(\tB\x03\xe0\x41\x02R\x0einternalUserId\"\x1f\n\x19GetLegacyBillingIdRequest:\x02\x18\x01\"D\n\x1aGetLegacyBillingIdResponse\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tbillingId:\x02\x18\x01\"\x9c\x01\n\x1a\x43reateAccountHandleRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12P\n\x06handle\x18\x02 \x01(\tB8\xfa\x42\x35r3\x10\x04\x18\x64\x32&^[a-zA-Z0-9][a-zA-Z0-9_-]+[a-zA-Z0-9]$\xba\x01\x04strmR\x06handle\":\n\x1b\x43reateAccountHandleResponse\x12\x1b\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06handle\"\x8e\x01\n\x19InitializeCheckoutRequest\x12I\n\x07plan_id\x18\x01 \x01(\tB0\xfa\x42-r+\x10\x01R\nENTERPRISER\x08\x42USINESSR\x0bSELF_HOSTEDR\x04\x46REER\x06planId\x12&\n\x07user_id\x18\x02 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\"D\n\x1aInitializeCheckoutResponse\x12&\n\x0c\x63heckout_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0b\x63heckoutUri\"~\n\x18GetCheckoutStatusRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\x12:\n\x13\x63heckout_session_id\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xd0\x01\x01R\x11\x63heckoutSessionId\"8\n\x19GetCheckoutStatusResponse\x12\x1b\n\x06status\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06status\"\x81\x01\n\x1bSetCheckoutCancelledRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\x12:\n\x13\x63heckout_session_id\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xd0\x01\x01R\x11\x63heckoutSessionId\"\x1e\n\x1cSetCheckoutCancelledResponse\"I\n\x1fInitializeCustomerPortalRequest\x12&\n\x07user_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x06userId\"W\n InitializeCustomerPortalResponse\x12\x33\n\x13\x63ustomer_portal_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x11\x63ustomerPortalUri2\xcf\x07\n\x0e\x41\x63\x63ountService\x12\x80\x01\n\x11GetAccountDetails\x12\x34.strmprivacy.api.account.v1.GetAccountDetailsRequest\x1a\x35.strmprivacy.api.account.v1.GetAccountDetailsResponse\x12\x83\x01\n\x12GetLegacyBillingId\x12\x35.strmprivacy.api.account.v1.GetLegacyBillingIdRequest\x1a\x36.strmprivacy.api.account.v1.GetLegacyBillingIdResponse\x12\x86\x01\n\x13\x43reateAccountHandle\x12\x36.strmprivacy.api.account.v1.CreateAccountHandleRequest\x1a\x37.strmprivacy.api.account.v1.CreateAccountHandleResponse\x12\x83\x01\n\x12InitializeCheckout\x12\x35.strmprivacy.api.account.v1.InitializeCheckoutRequest\x1a\x36.strmprivacy.api.account.v1.InitializeCheckoutResponse\x12\x80\x01\n\x11GetCheckoutStatus\x12\x34.strmprivacy.api.account.v1.GetCheckoutStatusRequest\x1a\x35.strmprivacy.api.account.v1.GetCheckoutStatusResponse\x12\x95\x01\n\x18InitializeCustomerPortal\x12;.strmprivacy.api.account.v1.InitializeCustomerPortalRequest\x1a<.strmprivacy.api.account.v1.InitializeCustomerPortalResponse\x12\x89\x01\n\x14SetCheckoutCancelled\x12\x37.strmprivacy.api.account.v1.SetCheckoutCancelledRequest\x1a\x38.strmprivacy.api.account.v1.SetCheckoutCancelledResponseBf\n\x1dio.strmprivacy.api.account.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;accountb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.account.v1.account_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.account.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/account/v1;account'
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['max_input_streams']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['handle']._serialized_options = b'\340A\001'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['subscription']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['organization_id']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._options = None
  _GETACCOUNTDETAILSRESPONSE.fields_by_name['internal_user_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDREQUEST._options = None
  _GETLEGACYBILLINGIDREQUEST._serialized_options = b'\030\001'
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._options = None
  _GETLEGACYBILLINGIDRESPONSE.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _GETLEGACYBILLINGIDRESPONSE._options = None
  _GETLEGACYBILLINGIDRESPONSE._serialized_options = b'\030\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLEREQUEST.fields_by_name['handle']._serialized_options = b'\372B5r3\020\004\030d2&^[a-zA-Z0-9][a-zA-Z0-9_-]+[a-zA-Z0-9]$\272\001\004strm'
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._options = None
  _CREATEACCOUNTHANDLERESPONSE.fields_by_name['handle']._serialized_options = b'\340A\002'
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._options = None
  _INITIALIZECHECKOUTREQUEST.fields_by_name['plan_id']._serialized_options = b'\372B-r+\020\001R\nENTERPRISER\010BUSINESSR\013SELF_HOSTEDR\004FREE'
  _INITIALIZECHECKOUTREQUEST.fields_by_name['user_id']._options = None
  _INITIALIZECHECKOUTREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._options = None
  _INITIALIZECHECKOUTRESPONSE.fields_by_name['checkout_uri']._serialized_options = b'\340A\002'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._options = None
  _GETCHECKOUTSTATUSREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\372B\007r\005\020\001\320\001\001'
  _GETCHECKOUTSTATUSRESPONSE.fields_by_name['status']._options = None
  _GETCHECKOUTSTATUSRESPONSE.fields_by_name['status']._serialized_options = b'\340A\002'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._options = None
  _SETCHECKOUTCANCELLEDREQUEST.fields_by_name['checkout_session_id']._serialized_options = b'\372B\007r\005\020\001\320\001\001'
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._options = None
  _INITIALIZECUSTOMERPORTALREQUEST.fields_by_name['user_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._options = None
  _INITIALIZECUSTOMERPORTALRESPONSE.fields_by_name['customer_portal_uri']._serialized_options = b'\340A\002'
  _GETACCOUNTDETAILSREQUEST._serialized_start=133
  _GETACCOUNTDETAILSREQUEST._serialized_end=205
  _GETACCOUNTDETAILSRESPONSE._serialized_start=208
  _GETACCOUNTDETAILSRESPONSE._serialized_end=523
  _GETLEGACYBILLINGIDREQUEST._serialized_start=525
  _GETLEGACYBILLINGIDREQUEST._serialized_end=556
  _GETLEGACYBILLINGIDRESPONSE._serialized_start=558
  _GETLEGACYBILLINGIDRESPONSE._serialized_end=626
  _CREATEACCOUNTHANDLEREQUEST._serialized_start=629
  _CREATEACCOUNTHANDLEREQUEST._serialized_end=785
  _CREATEACCOUNTHANDLERESPONSE._serialized_start=787
  _CREATEACCOUNTHANDLERESPONSE._serialized_end=845
  _INITIALIZECHECKOUTREQUEST._serialized_start=848
  _INITIALIZECHECKOUTREQUEST._serialized_end=990
  _INITIALIZECHECKOUTRESPONSE._serialized_start=992
  _INITIALIZECHECKOUTRESPONSE._serialized_end=1060
  _GETCHECKOUTSTATUSREQUEST._serialized_start=1062
  _GETCHECKOUTSTATUSREQUEST._serialized_end=1188
  _GETCHECKOUTSTATUSRESPONSE._serialized_start=1190
  _GETCHECKOUTSTATUSRESPONSE._serialized_end=1246
  _SETCHECKOUTCANCELLEDREQUEST._serialized_start=1249
  _SETCHECKOUTCANCELLEDREQUEST._serialized_end=1378
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_start=1380
  _SETCHECKOUTCANCELLEDRESPONSE._serialized_end=1410
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_start=1412
  _INITIALIZECUSTOMERPORTALREQUEST._serialized_end=1485
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_start=1487
  _INITIALIZECUSTOMERPORTALRESPONSE._serialized_end=1574
  _ACCOUNTSERVICE._serialized_start=1577
  _ACCOUNTSERVICE._serialized_end=2552
# @@protoc_insertion_point(module_scope)
