# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/projects/v1/projects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/projects/v1/projects_v1.proto\x12\x1bstrmprivacy.api.projects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"<\n\x11GetProjectRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"Y\n\x12GetProjectResponse\x12\x43\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x03\xe0\x41\x02R\x07project\"\x15\n\x13ListProjectsRequest\"X\n\x14ListProjectsResponse\x12@\n\x08projects\x18\x01 \x03(\x0b\x32$.strmprivacy.api.entities.v1.ProjectR\x08projects\"`\n\x14\x43reateProjectRequest\x12H\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07project\"\\\n\x15\x43reateProjectResponse\x12\x43\n\x07project\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x03\xe0\x41\x02R\x07project\"?\n\x14\x44\x65leteProjectRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x17\n\x15\x44\x65leteProjectResponse\"k\n\x18\x41\x64\x64ProjectMembersRequest\x12&\n\x06\x65mails\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02`\x01R\x06\x65mails\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x1b\n\x19\x41\x64\x64ProjectMembersResponse\"n\n\x1bRemoveProjectMembersRequest\x12&\n\x06\x65mails\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02`\x01R\x06\x65mails\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x1e\n\x1cRemoveProjectMembersResponse\"D\n\x19ListProjectMembersRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"h\n\x1aListProjectMembersResponse\x12J\n\x0fproject_members\x18\x01 \x03(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x0eprojectMembers2\x80\x07\n\x0fProjectsService\x12s\n\x0cListProjects\x12\x30.strmprivacy.api.projects.v1.ListProjectsRequest\x1a\x31.strmprivacy.api.projects.v1.ListProjectsResponse\x12v\n\rCreateProject\x12\x31.strmprivacy.api.projects.v1.CreateProjectRequest\x1a\x32.strmprivacy.api.projects.v1.CreateProjectResponse\x12v\n\rDeleteProject\x12\x31.strmprivacy.api.projects.v1.DeleteProjectRequest\x1a\x32.strmprivacy.api.projects.v1.DeleteProjectResponse\x12m\n\nGetProject\x12..strmprivacy.api.projects.v1.GetProjectRequest\x1a/.strmprivacy.api.projects.v1.GetProjectResponse\x12\x82\x01\n\x11\x41\x64\x64ProjectMembers\x12\x35.strmprivacy.api.projects.v1.AddProjectMembersRequest\x1a\x36.strmprivacy.api.projects.v1.AddProjectMembersResponse\x12\x8b\x01\n\x14RemoveProjectMembers\x12\x38.strmprivacy.api.projects.v1.RemoveProjectMembersRequest\x1a\x39.strmprivacy.api.projects.v1.RemoveProjectMembersResponse\x12\x85\x01\n\x12ListProjectMembers\x12\x36.strmprivacy.api.projects.v1.ListProjectMembersRequest\x1a\x37.strmprivacy.api.projects.v1.ListProjectMembersResponseBi\n\x1eio.strmprivacy.api.projects.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projectsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.projects.v1.projects_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.projects.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/projects/v1;projects'
  _GETPROJECTREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETPROJECTRESPONSE.fields_by_name['project']._options = None
  _GETPROJECTRESPONSE.fields_by_name['project']._serialized_options = b'\340A\002'
  _CREATEPROJECTREQUEST.fields_by_name['project']._options = None
  _CREATEPROJECTREQUEST.fields_by_name['project']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPROJECTRESPONSE.fields_by_name['project']._options = None
  _CREATEPROJECTRESPONSE.fields_by_name['project']._serialized_options = b'\340A\002'
  _DELETEPROJECTREQUEST.fields_by_name['project_id']._options = None
  _DELETEPROJECTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['emails']._options = None
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['emails']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002`\001'
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['project_id']._options = None
  _ADDPROJECTMEMBERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['emails']._options = None
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['emails']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002`\001'
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['project_id']._options = None
  _REMOVEPROJECTMEMBERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTPROJECTMEMBERSREQUEST.fields_by_name['project_id']._options = None
  _LISTPROJECTMEMBERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETPROJECTREQUEST._serialized_start=183
  _GETPROJECTREQUEST._serialized_end=243
  _GETPROJECTRESPONSE._serialized_start=245
  _GETPROJECTRESPONSE._serialized_end=334
  _LISTPROJECTSREQUEST._serialized_start=336
  _LISTPROJECTSREQUEST._serialized_end=357
  _LISTPROJECTSRESPONSE._serialized_start=359
  _LISTPROJECTSRESPONSE._serialized_end=447
  _CREATEPROJECTREQUEST._serialized_start=449
  _CREATEPROJECTREQUEST._serialized_end=545
  _CREATEPROJECTRESPONSE._serialized_start=547
  _CREATEPROJECTRESPONSE._serialized_end=639
  _DELETEPROJECTREQUEST._serialized_start=641
  _DELETEPROJECTREQUEST._serialized_end=704
  _DELETEPROJECTRESPONSE._serialized_start=706
  _DELETEPROJECTRESPONSE._serialized_end=729
  _ADDPROJECTMEMBERSREQUEST._serialized_start=731
  _ADDPROJECTMEMBERSREQUEST._serialized_end=838
  _ADDPROJECTMEMBERSRESPONSE._serialized_start=840
  _ADDPROJECTMEMBERSRESPONSE._serialized_end=867
  _REMOVEPROJECTMEMBERSREQUEST._serialized_start=869
  _REMOVEPROJECTMEMBERSREQUEST._serialized_end=979
  _REMOVEPROJECTMEMBERSRESPONSE._serialized_start=981
  _REMOVEPROJECTMEMBERSRESPONSE._serialized_end=1011
  _LISTPROJECTMEMBERSREQUEST._serialized_start=1013
  _LISTPROJECTMEMBERSREQUEST._serialized_end=1081
  _LISTPROJECTMEMBERSRESPONSE._serialized_start=1083
  _LISTPROJECTMEMBERSRESPONSE._serialized_end=1187
  _PROJECTSSERVICE._serialized_start=1190
  _PROJECTSSERVICE._serialized_end=2086
# @@protoc_insertion_point(module_scope)
