# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.credentials.v1 import credentials_v1_pb2 as strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2


class CredentialsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCredentials = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/ListCredentials',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsResponse.FromString,
                )
        self.GetCredential = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/GetCredential',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialResponse.FromString,
                )
        self.CreateCredential = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/CreateCredential',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialResponse.FromString,
                )
        self.DeleteCredential = channel.unary_unary(
                '/strmprivacy.api.credentials.v1.CredentialsService/DeleteCredential',
                request_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialResponse.FromString,
                )


class CredentialsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCredentials(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCredential(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCredential(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCredential(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CredentialsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCredentials,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsResponse.SerializeToString,
            ),
            'GetCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCredential,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialResponse.SerializeToString,
            ),
            'CreateCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCredential,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialResponse.SerializeToString,
            ),
            'DeleteCredential': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCredential,
                    request_deserializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.credentials.v1.CredentialsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CredentialsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/ListCredentials',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.ListCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/GetCredential',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.GetCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/CreateCredential',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.CreateCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCredential(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.credentials.v1.CredentialsService/DeleteCredential',
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialRequest.SerializeToString,
            strmprivacy_dot_api_dot_credentials_dot_v1_dot_credentials__v1__pb2.DeleteCredentialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
