# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/key_streams/v1/key_streams.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0strmprivacy/api/key_streams/v1/key_streams.proto\x12\x1estrmprivacy.api.key_streams.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"n\n\x15ListKeyStreamsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"a\n\x16ListKeyStreamsResponse\x12G\n\x0bkey_streams\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KeyStreamR\nkeyStreams\"\\\n\x13GetKeyStreamRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"b\n\x14GetKeyStreamResponse\x12J\n\nkey_stream\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStreamB\x03\xe0\x41\x02R\tkeyStream2\x8f\x02\n\x11KeyStreamsService\x12\x7f\n\x0eListKeyStreams\x12\x35.strmprivacy.api.key_streams.v1.ListKeyStreamsRequest\x1a\x36.strmprivacy.api.key_streams.v1.ListKeyStreamsResponse\x12y\n\x0cGetKeyStream\x12\x33.strmprivacy.api.key_streams.v1.GetKeyStreamRequest\x1a\x34.strmprivacy.api.key_streams.v1.GetKeyStreamResponseBr\n!io.strmprivacy.api.key_streams.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streamsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.key_streams.v1.key_streams_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.key_streams.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/key_streams/v1;key_streams'
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._options = None
  _LISTKEYSTREAMSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETKEYSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKEYSTREAMRESPONSE.fields_by_name['key_stream']._options = None
  _GETKEYSTREAMRESPONSE.fields_by_name['key_stream']._serialized_options = b'\340A\002'
  _LISTKEYSTREAMSREQUEST._serialized_start=189
  _LISTKEYSTREAMSREQUEST._serialized_end=299
  _LISTKEYSTREAMSRESPONSE._serialized_start=301
  _LISTKEYSTREAMSRESPONSE._serialized_end=398
  _GETKEYSTREAMREQUEST._serialized_start=400
  _GETKEYSTREAMREQUEST._serialized_end=492
  _GETKEYSTREAMRESPONSE._serialized_start=494
  _GETKEYSTREAMRESPONSE._serialized_end=592
  _KEYSTREAMSSERVICE._serialized_start=595
  _KEYSTREAMSSERVICE._serialized_end=866
# @@protoc_insertion_point(module_scope)
