# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/event_contracts/v1/event_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/event_contracts/v1/event_contracts_v1.proto\x12\"strmprivacy.api.event_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xc0\x03\n\x19ListEventContractsRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x1b\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x06\x66ilter\x12\x1b\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06handle\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x04name\x12\\\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01R\rpublicPrivate\x12J\n\nschema_ref\x18\x06 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x01R\tschemaRef\x12?\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01R\nindustries\"q\n\x1aListEventContractsResponse\x12S\n\x0f\x65vent_contracts\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\x0e\x65ventContracts\"}\n\x17GetEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12?\n\x03ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefR\x03ref\"\x8e\x01\n\x18GetEventContractResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xb1\x01\n\x1a\x43reateEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12Q\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\"\x91\x01\n\x1b\x43reateEventContractResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\x9e\x02\n\x1aUpdateEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12V\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractB\x03\xe0\x41\x02R\reventContract\x12\x1f\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12\"\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x91\x01\n\x1bUpdateEventContractResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\xc7\x01\n\x1c\x41\x63tivateEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12`\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1f\n\x1d\x41\x63tivateEventContractResponse\"\xc5\x01\n\x1a\x44\x65leteEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12`\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1d\n\x1b\x44\x65leteEventContractResponse\"\xc6\x01\n\x1b\x41rchiveEventContractRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12`\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1e\n\x1c\x41rchiveEventContractResponse\"\xb4\x01\n\x1bValidateMaskedFieldsRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12N\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsR\x0cmaskedFields\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\xd6\x03\n\x1cValidateMaskedFieldsResponse\x12^\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x46.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.ErrorR\x06\x65rrors\x1a\xd5\x02\n\x05\x45rror\x12[\n\x12\x65vent_contract_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefR\x10\x65ventContractRef\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12i\n\x06\x65rrors\x18\x03 \x03(\x0b\x32Q.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error.FieldErrorR\x06\x65rrors\x1aj\n\nFieldError\x12#\n\rfield_pattern\x18\x01 \x01(\tR\x0c\x66ieldPattern\x12\x1d\n\nfield_type\x18\x02 \x01(\tR\tfieldType\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"c\n GetEventContractAndSchemaRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefR\x03ref\"\xd6\x01\n!GetEventContractAndSchemaResponse\x12Q\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractR\reventContract\x12;\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12!\n\x0c\x63onfluent_id\x18\x03 \x01(\x05R\x0b\x63onfluentId2\x8a\x0b\n\x15\x45ventContractsService\x12\x93\x01\n\x12ListEventContracts\x12=.strmprivacy.api.event_contracts.v1.ListEventContractsRequest\x1a>.strmprivacy.api.event_contracts.v1.ListEventContractsResponse\x12\x8d\x01\n\x10GetEventContract\x12;.strmprivacy.api.event_contracts.v1.GetEventContractRequest\x1a<.strmprivacy.api.event_contracts.v1.GetEventContractResponse\x12\x96\x01\n\x13\x43reateEventContract\x12>.strmprivacy.api.event_contracts.v1.CreateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.CreateEventContractResponse\x12\x96\x01\n\x13UpdateEventContract\x12>.strmprivacy.api.event_contracts.v1.UpdateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.UpdateEventContractResponse\x12\x9c\x01\n\x15\x41\x63tivateEventContract\x12@.strmprivacy.api.event_contracts.v1.ActivateEventContractRequest\x1a\x41.strmprivacy.api.event_contracts.v1.ActivateEventContractResponse\x12\x96\x01\n\x13\x44\x65leteEventContract\x12>.strmprivacy.api.event_contracts.v1.DeleteEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.DeleteEventContractResponse\x12\x99\x01\n\x14\x41rchiveEventContract\x12?.strmprivacy.api.event_contracts.v1.ArchiveEventContractRequest\x1a@.strmprivacy.api.event_contracts.v1.ArchiveEventContractResponse\x12\x99\x01\n\x14ValidateMaskedFields\x12?.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsRequest\x1a@.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse\x12\xa8\x01\n\x19GetEventContractAndSchema\x12\x44.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaRequest\x1a\x45.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaResponseB~\n%io.strmprivacy.api.event_contracts.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contractsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.event_contracts.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contracts'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _LISTEVENTCONTRACTSREQUEST._serialized_start=214
  _LISTEVENTCONTRACTSREQUEST._serialized_end=662
  _LISTEVENTCONTRACTSRESPONSE._serialized_start=664
  _LISTEVENTCONTRACTSRESPONSE._serialized_end=777
  _GETEVENTCONTRACTREQUEST._serialized_start=779
  _GETEVENTCONTRACTREQUEST._serialized_end=904
  _GETEVENTCONTRACTRESPONSE._serialized_start=907
  _GETEVENTCONTRACTRESPONSE._serialized_end=1049
  _CREATEEVENTCONTRACTREQUEST._serialized_start=1052
  _CREATEEVENTCONTRACTREQUEST._serialized_end=1229
  _CREATEEVENTCONTRACTRESPONSE._serialized_start=1232
  _CREATEEVENTCONTRACTRESPONSE._serialized_end=1377
  _UPDATEEVENTCONTRACTREQUEST._serialized_start=1380
  _UPDATEEVENTCONTRACTREQUEST._serialized_end=1666
  _UPDATEEVENTCONTRACTRESPONSE._serialized_start=1669
  _UPDATEEVENTCONTRACTRESPONSE._serialized_end=1814
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_start=1817
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_end=2016
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_start=2018
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_end=2049
  _DELETEEVENTCONTRACTREQUEST._serialized_start=2052
  _DELETEEVENTCONTRACTREQUEST._serialized_end=2249
  _DELETEEVENTCONTRACTRESPONSE._serialized_start=2251
  _DELETEEVENTCONTRACTRESPONSE._serialized_end=2280
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_start=2283
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_end=2481
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_start=2483
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_end=2513
  _VALIDATEMASKEDFIELDSREQUEST._serialized_start=2516
  _VALIDATEMASKEDFIELDSREQUEST._serialized_end=2696
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_start=2699
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_end=3169
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_start=2828
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_end=3169
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=3063
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=3169
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_start=3171
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_end=3270
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_start=3273
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_end=3487
  _EVENTCONTRACTSSERVICE._serialized_start=3490
  _EVENTCONTRACTSSERVICE._serialized_end=4908
# @@protoc_insertion_point(module_scope)
