# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/kafka_clusters/v1/kafka_clusters_v1.proto\x12!strmprivacy.api.kafka_clusters.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"t\n\x18ListKafkaClustersRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12*\n\nproject_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"m\n\x19ListKafkaClustersResponse\x12P\n\x0ekafka_clusters\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\rkafkaClusters\"\xbf\x01\n\x19\x44\x65leteKafkaClusterRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12*\n\nproject_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"\x1c\n\x1a\x44\x65leteKafkaClusterResponse\"k\n\x19\x43reateKafkaClusterRequest\x12N\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\x0ckafkaCluster\"l\n\x1a\x43reateKafkaClusterResponse\x12N\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\x0ckafkaCluster\"\xbc\x01\n\x16GetKafkaClusterRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12*\n\nproject_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"i\n\x17GetKafkaClusterResponse\x12N\n\rkafka_cluster\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaClusterR\x0ckafkaCluster2\xda\x04\n\x14KafkaClustersService\x12\x8e\x01\n\x11ListKafkaClusters\x12;.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersRequest\x1a<.strmprivacy.api.kafka_clusters.v1.ListKafkaClustersResponse\x12\x88\x01\n\x0fGetKafkaCluster\x12\x39.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterRequest\x1a:.strmprivacy.api.kafka_clusters.v1.GetKafkaClusterResponse\x12\x91\x01\n\x12\x44\x65leteKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.DeleteKafkaClusterResponse\x12\x91\x01\n\x12\x43reateKafkaCluster\x12<.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterRequest\x1a=.strmprivacy.api.kafka_clusters.v1.CreateKafkaClusterResponseB{\n$io.strmprivacy.api.kafka_clusters.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clustersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.kafka_clusters.v1.kafka_clusters_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.kafka_clusters.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_clusters/v1;kafka_clusters'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKACLUSTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _DELETEKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._options = None
  _GETKAFKACLUSTERREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTKAFKACLUSTERSREQUEST._serialized_start=168
  _LISTKAFKACLUSTERSREQUEST._serialized_end=284
  _LISTKAFKACLUSTERSRESPONSE._serialized_start=286
  _LISTKAFKACLUSTERSRESPONSE._serialized_end=395
  _DELETEKAFKACLUSTERREQUEST._serialized_start=398
  _DELETEKAFKACLUSTERREQUEST._serialized_end=589
  _DELETEKAFKACLUSTERRESPONSE._serialized_start=591
  _DELETEKAFKACLUSTERRESPONSE._serialized_end=619
  _CREATEKAFKACLUSTERREQUEST._serialized_start=621
  _CREATEKAFKACLUSTERREQUEST._serialized_end=728
  _CREATEKAFKACLUSTERRESPONSE._serialized_start=730
  _CREATEKAFKACLUSTERRESPONSE._serialized_end=838
  _GETKAFKACLUSTERREQUEST._serialized_start=841
  _GETKAFKACLUSTERREQUEST._serialized_end=1029
  _GETKAFKACLUSTERRESPONSE._serialized_start=1031
  _GETKAFKACLUSTERRESPONSE._serialized_end=1136
  _KAFKACLUSTERSSERVICE._serialized_start=1139
  _KAFKACLUSTERSSERVICE._serialized_end=1741
# @@protoc_insertion_point(module_scope)
