# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_connectors/v1/data_connectors_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/data_connectors/v1/data_connectors_v1.proto\x12\"strmprivacy.api.data_connectors.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xc1\x01\n\x19ListDataConnectorsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials\x12\'\n\nproject_id\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"q\n\x1aListDataConnectorsResponse\x12S\n\x0f\x64\x61ta_connectors\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorR\x0e\x64\x61taConnectors\"\x85\x01\n\x1a\x44\x65leteDataConnectorRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"\x1d\n\x1b\x44\x65leteDataConnectorResponse\"y\n\x1a\x43reateDataConnectorRequest\x12[\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\rdataConnector\"u\n\x1b\x43reateDataConnectorResponse\x12V\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorB\x03\xe0\x41\x02R\rdataConnector\"\xb3\x01\n\x17GetDataConnectorRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials\"m\n\x18GetDataConnectorResponse\x12Q\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorR\rdataConnector2\xef\x04\n\x15\x44\x61taConnectorsService\x12\x93\x01\n\x12ListDataConnectors\x12=.strmprivacy.api.data_connectors.v1.ListDataConnectorsRequest\x1a>.strmprivacy.api.data_connectors.v1.ListDataConnectorsResponse\x12\x8d\x01\n\x10GetDataConnector\x12;.strmprivacy.api.data_connectors.v1.GetDataConnectorRequest\x1a<.strmprivacy.api.data_connectors.v1.GetDataConnectorResponse\x12\x96\x01\n\x13\x44\x65leteDataConnector\x12>.strmprivacy.api.data_connectors.v1.DeleteDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.DeleteDataConnectorResponse\x12\x96\x01\n\x13\x43reateDataConnector\x12>.strmprivacy.api.data_connectors.v1.CreateDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.CreateDataConnectorResponseB~\n%io.strmprivacy.api.data_connectors.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectorsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.data_connectors.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectors'
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._options = None
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEDATACONNECTORRESPONSE.fields_by_name['data_connector']._options = None
  _CREATEDATACONNECTORRESPONSE.fields_by_name['data_connector']._serialized_options = b'\340A\002'
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTDATACONNECTORSREQUEST._serialized_start=205
  _LISTDATACONNECTORSREQUEST._serialized_end=398
  _LISTDATACONNECTORSRESPONSE._serialized_start=400
  _LISTDATACONNECTORSRESPONSE._serialized_end=513
  _DELETEDATACONNECTORREQUEST._serialized_start=516
  _DELETEDATACONNECTORREQUEST._serialized_end=649
  _DELETEDATACONNECTORRESPONSE._serialized_start=651
  _DELETEDATACONNECTORRESPONSE._serialized_end=680
  _CREATEDATACONNECTORREQUEST._serialized_start=682
  _CREATEDATACONNECTORREQUEST._serialized_end=803
  _CREATEDATACONNECTORRESPONSE._serialized_start=805
  _CREATEDATACONNECTORRESPONSE._serialized_end=922
  _GETDATACONNECTORREQUEST._serialized_start=925
  _GETDATACONNECTORREQUEST._serialized_end=1104
  _GETDATACONNECTORRESPONSE._serialized_start=1106
  _GETDATACONNECTORRESPONSE._serialized_end=1215
  _DATACONNECTORSSERVICE._serialized_start=1218
  _DATACONNECTORSSERVICE._serialized_end=1841
# @@protoc_insertion_point(module_scope)
