# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/purpose_mapping/v1/purpose_mapping_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/purpose_mapping/v1/purpose_mapping_v1.proto\x12\"strmprivacy.api.purpose_mapping.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x1c\n\x1aListPurposeMappingsRequest\"u\n\x1bListPurposeMappingsResponse\x12V\n\x10purpose_mappings\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingR\x0fpurposeMappings\"}\n\x1b\x43reatePurposeMappingRequest\x12^\n\x0fpurpose_mapping\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0epurposeMapping\"y\n\x1c\x43reatePurposeMappingResponse\x12Y\n\x0fpurpose_mapping\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingB\x03\xe0\x41\x02R\x0epurposeMapping\"9\n\x18GetPurposeMappingRequest\x12\x1d\n\x05level\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\x05level\"v\n\x19GetPurposeMappingResponse\x12Y\n\x0fpurpose_mapping\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.PurposeMappingB\x03\xe0\x41\x02R\x0epurposeMapping2\xdf\x03\n\x15PurposeMappingService\x12\x96\x01\n\x13ListPurposeMappings\x12>.strmprivacy.api.purpose_mapping.v1.ListPurposeMappingsRequest\x1a?.strmprivacy.api.purpose_mapping.v1.ListPurposeMappingsResponse\x12\x90\x01\n\x11GetPurposeMapping\x12<.strmprivacy.api.purpose_mapping.v1.GetPurposeMappingRequest\x1a=.strmprivacy.api.purpose_mapping.v1.GetPurposeMappingResponse\x12\x99\x01\n\x14\x43reatePurposeMapping\x12?.strmprivacy.api.purpose_mapping.v1.CreatePurposeMappingRequest\x1a@.strmprivacy.api.purpose_mapping.v1.CreatePurposeMappingResponseB~\n%io.strmprivacy.api.purpose_mapping.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/purpose_mapping/v1;purpose_mappingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.purpose_mapping.v1.purpose_mapping_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.purpose_mapping.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/purpose_mapping/v1;purpose_mapping'
  _CREATEPURPOSEMAPPINGREQUEST.fields_by_name['purpose_mapping']._options = None
  _CREATEPURPOSEMAPPINGREQUEST.fields_by_name['purpose_mapping']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._options = None
  _CREATEPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._serialized_options = b'\340A\002'
  _GETPURPOSEMAPPINGREQUEST.fields_by_name['level']._options = None
  _GETPURPOSEMAPPINGREQUEST.fields_by_name['level']._serialized_options = b'\372B\004\032\002(\000'
  _GETPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._options = None
  _GETPURPOSEMAPPINGRESPONSE.fields_by_name['purpose_mapping']._serialized_options = b'\340A\002'
  _LISTPURPOSEMAPPINGSREQUEST._serialized_start=204
  _LISTPURPOSEMAPPINGSREQUEST._serialized_end=232
  _LISTPURPOSEMAPPINGSRESPONSE._serialized_start=234
  _LISTPURPOSEMAPPINGSRESPONSE._serialized_end=351
  _CREATEPURPOSEMAPPINGREQUEST._serialized_start=353
  _CREATEPURPOSEMAPPINGREQUEST._serialized_end=478
  _CREATEPURPOSEMAPPINGRESPONSE._serialized_start=480
  _CREATEPURPOSEMAPPINGRESPONSE._serialized_end=601
  _GETPURPOSEMAPPINGREQUEST._serialized_start=603
  _GETPURPOSEMAPPINGREQUEST._serialized_end=660
  _GETPURPOSEMAPPINGRESPONSE._serialized_start=662
  _GETPURPOSEMAPPINGRESPONSE._serialized_end=780
  _PURPOSEMAPPINGSERVICE._serialized_start=783
  _PURPOSEMAPPINGSERVICE._serialized_end=1262
# @@protoc_insertion_point(module_scope)
