# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.event_contracts.v1 import event_contracts_v1_pb2 as strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2


class EventContractsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListEventContracts = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ListEventContracts',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsResponse.FromString,
                )
        self.GetEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractResponse.FromString,
                )
        self.CreateEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/CreateEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractResponse.FromString,
                )
        self.UpdateEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/UpdateEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractResponse.FromString,
                )
        self.ActivateEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ActivateEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractResponse.FromString,
                )
        self.DeleteEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/DeleteEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractResponse.FromString,
                )
        self.ArchiveEventContract = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ArchiveEventContract',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractResponse.FromString,
                )
        self.ValidateMaskedFields = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/ValidateMaskedFields',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsResponse.FromString,
                )
        self.GetEventContractAndSchema = channel.unary_unary(
                '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContractAndSchema',
                request_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaResponse.FromString,
                )


class EventContractsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListEventContracts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveEventContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateMaskedFields(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventContractAndSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventContractsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListEventContracts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventContracts,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsResponse.SerializeToString,
            ),
            'GetEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractResponse.SerializeToString,
            ),
            'CreateEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractResponse.SerializeToString,
            ),
            'UpdateEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractResponse.SerializeToString,
            ),
            'ActivateEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractResponse.SerializeToString,
            ),
            'DeleteEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractResponse.SerializeToString,
            ),
            'ArchiveEventContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveEventContract,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractResponse.SerializeToString,
            ),
            'ValidateMaskedFields': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateMaskedFields,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsResponse.SerializeToString,
            ),
            'GetEventContractAndSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEventContractAndSchema,
                    request_deserializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.event_contracts.v1.EventContractsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventContractsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListEventContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ListEventContracts',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ListEventContractsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/CreateEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.CreateEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/UpdateEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.UpdateEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ActivateEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ActivateEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/DeleteEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.DeleteEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveEventContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ArchiveEventContract',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ArchiveEventContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateMaskedFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/ValidateMaskedFields',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.ValidateMaskedFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEventContractAndSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.event_contracts.v1.EventContractsService/GetEventContractAndSchema',
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_event__contracts_dot_v1_dot_event__contracts__v1__pb2.GetEventContractAndSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
