# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_contracts.v1 import data_contracts_v1_pb2 as strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2


class DataContractsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataContracts = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ListDataContracts',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsResponse.FromString,
                )
        self.GetDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractResponse.FromString,
                )
        self.CreateDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/CreateDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractResponse.FromString,
                )
        self.UpdateDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/UpdateDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractResponse.FromString,
                )
        self.ReviewDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ReviewDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractResponse.FromString,
                )
        self.ActivateDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ActivateDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractResponse.FromString,
                )
        self.DeleteDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/DeleteDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractResponse.FromString,
                )
        self.ArchiveDataContract = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ArchiveDataContract',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractResponse.FromString,
                )
        self.GetDataContractSchemaCode = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaCode',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeResponse.FromString,
                )
        self.GetDataContractSchemaDefinition = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaDefinition',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionResponse.FromString,
                )
        self.ValidateDataContractsMaskedFields = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/ValidateDataContractsMaskedFields',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsResponse.FromString,
                )
        self.SimpleSchemaDryRun = channel.unary_unary(
                '/strmprivacy.api.data_contracts.v1.DataContractsService/SimpleSchemaDryRun',
                request_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunResponse.FromString,
                )


class DataContractsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataContracts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReviewDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataContractSchemaCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataContractSchemaDefinition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDataContractsMaskedFields(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimpleSchemaDryRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataContractsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataContracts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataContracts,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsResponse.SerializeToString,
            ),
            'GetDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractResponse.SerializeToString,
            ),
            'CreateDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractResponse.SerializeToString,
            ),
            'UpdateDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractResponse.SerializeToString,
            ),
            'ReviewDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ReviewDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractResponse.SerializeToString,
            ),
            'ActivateDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractResponse.SerializeToString,
            ),
            'DeleteDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractResponse.SerializeToString,
            ),
            'ArchiveDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveDataContract,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractResponse.SerializeToString,
            ),
            'GetDataContractSchemaCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataContractSchemaCode,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeResponse.SerializeToString,
            ),
            'GetDataContractSchemaDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataContractSchemaDefinition,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionResponse.SerializeToString,
            ),
            'ValidateDataContractsMaskedFields': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDataContractsMaskedFields,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsResponse.SerializeToString,
            ),
            'SimpleSchemaDryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.SimpleSchemaDryRun,
                    request_deserializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_contracts.v1.DataContractsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataContractsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataContracts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ListDataContracts',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ListDataContractsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/CreateDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.CreateDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/UpdateDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.UpdateDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReviewDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ReviewDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ReviewDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ActivateDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ActivateDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/DeleteDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.DeleteDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ArchiveDataContract',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ArchiveDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataContractSchemaCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaCode',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataContractSchemaDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/GetDataContractSchemaDefinition',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.GetDataContractSchemaDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateDataContractsMaskedFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/ValidateDataContractsMaskedFields',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.ValidateDataContractsMaskedFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimpleSchemaDryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_contracts.v1.DataContractsService/SimpleSchemaDryRun',
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__contracts_dot_v1_dot_data__contracts__v1__pb2.SimpleSchemaDryRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
