# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.policies.v1 import policies_v1_pb2 as strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2


class PoliciesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPolicies = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/ListPolicies',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesResponse.FromString,
                )
        self.GetPolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/GetPolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyResponse.FromString,
                )
        self.DeletePolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/DeletePolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyResponse.FromString,
                )
        self.CreatePolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/CreatePolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyResponse.FromString,
                )
        self.UpdatePolicy = channel.unary_unary(
                '/strmprivacy.api.policies.v1.PoliciesService/UpdatePolicy',
                request_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyResponse.FromString,
                )


class PoliciesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPolicies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PoliciesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPolicies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPolicies,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesResponse.SerializeToString,
            ),
            'GetPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyResponse.SerializeToString,
            ),
            'DeletePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyResponse.SerializeToString,
            ),
            'CreatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyResponse.SerializeToString,
            ),
            'UpdatePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePolicy,
                    request_deserializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.policies.v1.PoliciesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PoliciesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPolicies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/ListPolicies',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.ListPoliciesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/GetPolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.GetPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/DeletePolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.DeletePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/CreatePolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.CreatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.policies.v1.PoliciesService/UpdatePolicy',
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyRequest.SerializeToString,
            strmprivacy_dot_api_dot_policies_dot_v1_dot_policies__v1__pb2.UpdatePolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
