# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_contracts/v1/data_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/data_contracts/v1/data_contracts_v1.proto\x12!strmprivacy.api.data_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x84\x03\n\x18ListDataContractsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x16\n\x06\x66ilter\x18\x02 \x01(\tR\x06\x66ilter\x12\x16\n\x06handle\x18\x03 \x01(\tR\x06handle\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12W\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateR\rpublicPrivate\x12:\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelR\x06labels\x12\x18\n\x07\x64omains\x18\x08 \x03(\tR\x07\x64omains\x12\x1e\n\nindustries\x18\t \x03(\tR\nindustries\x12\'\n\nproject_id\x18\n \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x9b\x03\n\x19ListDataContractsResponse\x12T\n\x0e\x64\x61ta_contracts\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x02\x18\x01R\rdataContracts\x12\x95\x01\n\x1c\x64\x61ta_contracts_and_checksums\x18\x02 \x03(\x0b\x32T.strmprivacy.api.data_contracts.v1.ListDataContractsResponse.DataContractAndChecksumR\x19\x64\x61taContractsAndChecksums\x1a\x8f\x01\n\x17\x44\x61taContractAndChecksum\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\x96\x01\n\x16GetDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x03ref\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\"\x8f\x01\n\x17GetDataContractResponse\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xcc\x01\n\x19\x43reateDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12X\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0c\x64\x61taContract\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x92\x01\n\x1a\x43reateDataContractResponse\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xfc\x03\n\x19UpdateDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12X\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0c\x64\x61taContract\x12#\n\x08\x63hecksum\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x63hecksum\x12\x45\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nupdateMask\x12~\n\x13\x63onsole_wizard_step\x18\x05 \x01(\x0e\x32N.strmprivacy.api.data_contracts.v1.UpdateDataContractRequest.ConsoleWizardStepR\x11\x63onsoleWizardStep\"k\n\x11\x43onsoleWizardStep\x12#\n\x1f\x43ONSOLE_WIZARD_STEP_UNSPECIFIED\x10\x00\x12\n\n\x06SCHEMA\x10\x01\x12\x12\n\x0e\x45VENT_CONTRACT\x10\x02\x12\x11\n\rDATA_CONTRACT\x10\x03\"\x92\x01\n\x1aUpdateDataContractResponse\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xfb\x01\n\x19ReviewDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12X\n\x11\x64\x61ta_contract_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\x12\x46\n\x19\x61pprover_external_user_id\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x16\x61pproverExternalUserId\"\x1c\n\x1aReviewDataContractResponse\"\xb5\x01\n\x1b\x41\x63tivateDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12X\n\x11\x64\x61ta_contract_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x1e\n\x1c\x41\x63tivateDataContractResponse\"\xdc\x01\n\x19\x44\x65leteDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12X\n\x11\x64\x61ta_contract_ref\x18\x04 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x1c\n\x1a\x44\x65leteDataContractResponse\"\xb4\x01\n\x1a\x41rchiveDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12X\n\x11\x64\x61ta_contract_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x1d\n\x1b\x41rchiveDataContractResponse\"\xb2\x01\n(ValidateDataContractsMaskedFieldsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12X\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cmaskedFields\"\x92\x04\n)ValidateDataContractsMaskedFieldsResponse\x12j\n\x06\x65rrors\x18\x01 \x03(\x0b\x32R.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.ErrorR\x06\x65rrors\x1a\xf8\x02\n\x05\x45rror\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12]\n\x11\x64\x61ta_contract_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02R\x0f\x64\x61taContractRef\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12u\n\x06\x65rrors\x18\x04 \x03(\x0b\x32].strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error.FieldErrorR\x06\x65rrors\x1aj\n\nFieldError\x12#\n\rfield_pattern\x18\x01 \x01(\tR\x0c\x66ieldPattern\x12\x1d\n\nfield_type\x18\x02 \x01(\tR\tfieldType\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"\xfd\x01\n GetDataContractSchemaCodeRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x41\n\x08language\x18\x03 \x01(\tB%\xfa\x42\"r R\x04javaR\ntypescriptR\x06pythonR\x04rustR\x08language\x12X\n\x11\x64\x61ta_contract_ref\x18\x04 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x7f\n!GetDataContractSchemaCodeResponse\x12\x1f\n\x08\x66ilename\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08\x66ilename\x12 \n\tdata_size\x18\x02 \x01(\x03\x42\x03\xe0\x41\x02R\x08\x64\x61taSize\x12\x17\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x03\xe0\x41\x02R\x04\x64\x61ta\"\x9a\x01\n&GetDataContractSchemaDefinitionRequest\x12!\n\x0c\x63onfluent_id\x18\x01 \x01(\x05R\x0b\x63onfluentId\x12M\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefR\nclusterRef\"N\n\'GetDataContractSchemaDefinitionResponse\x12#\n\ndefinition\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ndefinition\"\x9b\x01\n\x19SimpleSchemaDryRunRequest\x12~\n\x18simple_schema_definition\x18\x01 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinitionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x16simpleSchemaDefinition\"\x97\x01\n\x1aSimpleSchemaDryRunResponse\x12y\n\x18simple_schema_definition\x18\x01 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinitionB\x03\xe0\x41\x02R\x16simpleSchemaDefinition2\xec\x0e\n\x14\x44\x61taContractsService\x12\x8e\x01\n\x11ListDataContracts\x12;.strmprivacy.api.data_contracts.v1.ListDataContractsRequest\x1a<.strmprivacy.api.data_contracts.v1.ListDataContractsResponse\x12\x88\x01\n\x0fGetDataContract\x12\x39.strmprivacy.api.data_contracts.v1.GetDataContractRequest\x1a:.strmprivacy.api.data_contracts.v1.GetDataContractResponse\x12\x91\x01\n\x12\x43reateDataContract\x12<.strmprivacy.api.data_contracts.v1.CreateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.CreateDataContractResponse\x12\x91\x01\n\x12UpdateDataContract\x12<.strmprivacy.api.data_contracts.v1.UpdateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.UpdateDataContractResponse\x12\x91\x01\n\x12ReviewDataContract\x12<.strmprivacy.api.data_contracts.v1.ReviewDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.ReviewDataContractResponse\x12\x97\x01\n\x14\x41\x63tivateDataContract\x12>.strmprivacy.api.data_contracts.v1.ActivateDataContractRequest\x1a?.strmprivacy.api.data_contracts.v1.ActivateDataContractResponse\x12\x91\x01\n\x12\x44\x65leteDataContract\x12<.strmprivacy.api.data_contracts.v1.DeleteDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.DeleteDataContractResponse\x12\x94\x01\n\x13\x41rchiveDataContract\x12=.strmprivacy.api.data_contracts.v1.ArchiveDataContractRequest\x1a>.strmprivacy.api.data_contracts.v1.ArchiveDataContractResponse\x12\xa6\x01\n\x19GetDataContractSchemaCode\x12\x43.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeRequest\x1a\x44.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeResponse\x12\xb8\x01\n\x1fGetDataContractSchemaDefinition\x12I.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionRequest\x1aJ.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionResponse\x12\xbe\x01\n!ValidateDataContractsMaskedFields\x12K.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsRequest\x1aL.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse\x12\x91\x01\n\x12SimpleSchemaDryRun\x12<.strmprivacy.api.data_contracts.v1.SimpleSchemaDryRunRequest\x1a=.strmprivacy.api.data_contracts.v1.SimpleSchemaDryRunResponseB{\n$io.strmprivacy.api.data_contracts.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contractsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.data_contracts.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contracts'
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['data_contract']._options = None
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['checksum']._options = None
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSRESPONSE.fields_by_name['data_contracts']._options = None
  _LISTDATACONTRACTSRESPONSE.fields_by_name['data_contracts']._serialized_options = b'\030\001'
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETDATACONTRACTRESPONSE.fields_by_name['data_contract']._options = None
  _GETDATACONTRACTRESPONSE.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _CREATEDATACONTRACTREQUEST.fields_by_name['data_contract']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['data_contract']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEDATACONTRACTREQUEST.fields_by_name['project_id']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _CREATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._options = None
  _CREATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._options = None
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['approver_external_user_id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['approver_external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DELETEDATACONTRACTREQUEST.fields_by_name['project_id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['masked_fields']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['masked_fields']._serialized_options = b'\372B\005\212\001\002\020\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._serialized_options = b'\340A\002'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._serialized_options = b'\372B\"r R\004javaR\ntypescriptR\006pythonR\004rust'
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['filename']._options = None
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['filename']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data_size']._options = None
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data_size']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data']._options = None
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE.fields_by_name['definition']._options = None
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE.fields_by_name['definition']._serialized_options = b'\340A\002'
  _SIMPLESCHEMADRYRUNREQUEST.fields_by_name['simple_schema_definition']._options = None
  _SIMPLESCHEMADRYRUNREQUEST.fields_by_name['simple_schema_definition']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SIMPLESCHEMADRYRUNRESPONSE.fields_by_name['simple_schema_definition']._options = None
  _SIMPLESCHEMADRYRUNRESPONSE.fields_by_name['simple_schema_definition']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSREQUEST._serialized_start=236
  _LISTDATACONTRACTSREQUEST._serialized_end=624
  _LISTDATACONTRACTSRESPONSE._serialized_start=627
  _LISTDATACONTRACTSRESPONSE._serialized_end=1038
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM._serialized_start=895
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM._serialized_end=1038
  _GETDATACONTRACTREQUEST._serialized_start=1041
  _GETDATACONTRACTREQUEST._serialized_end=1191
  _GETDATACONTRACTRESPONSE._serialized_start=1194
  _GETDATACONTRACTRESPONSE._serialized_end=1337
  _CREATEDATACONTRACTREQUEST._serialized_start=1340
  _CREATEDATACONTRACTREQUEST._serialized_end=1544
  _CREATEDATACONTRACTRESPONSE._serialized_start=1547
  _CREATEDATACONTRACTRESPONSE._serialized_end=1693
  _UPDATEDATACONTRACTREQUEST._serialized_start=1696
  _UPDATEDATACONTRACTREQUEST._serialized_end=2204
  _UPDATEDATACONTRACTREQUEST_CONSOLEWIZARDSTEP._serialized_start=2097
  _UPDATEDATACONTRACTREQUEST_CONSOLEWIZARDSTEP._serialized_end=2204
  _UPDATEDATACONTRACTRESPONSE._serialized_start=2207
  _UPDATEDATACONTRACTRESPONSE._serialized_end=2353
  _REVIEWDATACONTRACTREQUEST._serialized_start=2356
  _REVIEWDATACONTRACTREQUEST._serialized_end=2607
  _REVIEWDATACONTRACTRESPONSE._serialized_start=2609
  _REVIEWDATACONTRACTRESPONSE._serialized_end=2637
  _ACTIVATEDATACONTRACTREQUEST._serialized_start=2640
  _ACTIVATEDATACONTRACTREQUEST._serialized_end=2821
  _ACTIVATEDATACONTRACTRESPONSE._serialized_start=2823
  _ACTIVATEDATACONTRACTRESPONSE._serialized_end=2853
  _DELETEDATACONTRACTREQUEST._serialized_start=2856
  _DELETEDATACONTRACTREQUEST._serialized_end=3076
  _DELETEDATACONTRACTRESPONSE._serialized_start=3078
  _DELETEDATACONTRACTRESPONSE._serialized_end=3106
  _ARCHIVEDATACONTRACTREQUEST._serialized_start=3109
  _ARCHIVEDATACONTRACTREQUEST._serialized_end=3289
  _ARCHIVEDATACONTRACTRESPONSE._serialized_start=3291
  _ARCHIVEDATACONTRACTRESPONSE._serialized_end=3320
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_start=3323
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_end=3501
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_start=3504
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_end=4034
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_start=3658
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_end=4034
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=3928
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=4034
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_start=4037
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_end=4290
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_start=4292
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_end=4419
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_start=4422
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_end=4576
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_start=4578
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_end=4656
  _SIMPLESCHEMADRYRUNREQUEST._serialized_start=4659
  _SIMPLESCHEMADRYRUNREQUEST._serialized_end=4814
  _SIMPLESCHEMADRYRUNRESPONSE._serialized_start=4817
  _SIMPLESCHEMADRYRUNRESPONSE._serialized_end=4968
  _DATACONTRACTSSERVICE._serialized_start=4971
  _DATACONTRACTSSERVICE._serialized_end=6871
# @@protoc_insertion_point(module_scope)
