# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/schemas/v1/schemas_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/schemas/v1/schemas_v1.proto\x12\x1astrmprivacy.api.schemas.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xbd\x03\n\x12ListSchemasRequest\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x01R\tbillingId\x12\x1b\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x06\x66ilter\x12\x1b\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06handle\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x04name\x12\\\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01R\rpublicPrivate\x12M\n\x0bschema_type\x18\x06 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x01R\nschemaType\x12?\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01R\nindustries\"T\n\x13ListSchemasResponse\x12=\n\x07schemas\x18\x01 \x03(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x07schemas\"\xbe\x01\n\x10GetSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x38\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefR\x03ref\x12M\n\x0b\x63luster_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefR\nclusterRef\"\x94\x01\n\x11GetSchemaResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12!\n\x0c\x63onfluent_id\x18\x02 \x01(\x05R\x0b\x63onfluentId\x12\x1f\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\x94\x01\n\x13\x43reateSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12;\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\"t\n\x14\x43reateSchemaResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\x81\x02\n\x13UpdateSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12@\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaB\x03\xe0\x41\x02R\x06schema\x12\x1f\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12\"\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"t\n\x14UpdateSchemaResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\xaa\x01\n\x15\x41\x63tivateSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12J\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x18\n\x16\x41\x63tivateSchemaResponse\"\xa8\x01\n\x13\x44\x65leteSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12J\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x16\n\x14\x44\x65leteSchemaResponse\"\xa9\x01\n\x14\x41rchiveSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12J\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x17\n\x15\x41rchiveSchemaResponse\"\x8f\x01\n\x14GetSchemaCodeRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x38\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefR\x03ref\x12\x1a\n\x08language\x18\x03 \x01(\tR\x08language\"d\n\x15GetSchemaCodeResponse\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x1b\n\tdata_size\x18\x02 \x01(\x03R\x08\x64\x61taSize\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"\x8e\x01\n\x1aGetSchemaDefinitionRequest\x12!\n\x0c\x63onfluent_id\x18\x01 \x01(\x05R\x0b\x63onfluentId\x12M\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefR\nclusterRef\"=\n\x1bGetSchemaDefinitionResponse\x12\x1e\n\ndefinition\x18\x01 \x01(\tR\ndefinition2\xb1\x08\n\x0eSchemasService\x12n\n\x0bListSchemas\x12..strmprivacy.api.schemas.v1.ListSchemasRequest\x1a/.strmprivacy.api.schemas.v1.ListSchemasResponse\x12h\n\tGetSchema\x12,.strmprivacy.api.schemas.v1.GetSchemaRequest\x1a-.strmprivacy.api.schemas.v1.GetSchemaResponse\x12q\n\x0c\x43reateSchema\x12/.strmprivacy.api.schemas.v1.CreateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.CreateSchemaResponse\x12q\n\x0cUpdateSchema\x12/.strmprivacy.api.schemas.v1.UpdateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.UpdateSchemaResponse\x12t\n\rGetSchemaCode\x12\x30.strmprivacy.api.schemas.v1.GetSchemaCodeRequest\x1a\x31.strmprivacy.api.schemas.v1.GetSchemaCodeResponse\x12w\n\x0e\x41\x63tivateSchema\x12\x31.strmprivacy.api.schemas.v1.ActivateSchemaRequest\x1a\x32.strmprivacy.api.schemas.v1.ActivateSchemaResponse\x12q\n\x0c\x44\x65leteSchema\x12/.strmprivacy.api.schemas.v1.DeleteSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.DeleteSchemaResponse\x12t\n\rArchiveSchema\x12\x30.strmprivacy.api.schemas.v1.ArchiveSchemaRequest\x1a\x31.strmprivacy.api.schemas.v1.ArchiveSchemaResponse\x12\x86\x01\n\x13GetSchemaDefinition\x12\x36.strmprivacy.api.schemas.v1.GetSchemaDefinitionRequest\x1a\x37.strmprivacy.api.schemas.v1.GetSchemaDefinitionResponseBf\n\x1dio.strmprivacy.api.schemas.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.schemas.v1.schemas_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.schemas.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemas'
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['filter']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['handle']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['name']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['labels']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['domains']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['industries']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSCHEMARESPONSE.fields_by_name['checksum']._options = None
  _GETSCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTSCHEMASREQUEST._serialized_start=190
  _LISTSCHEMASREQUEST._serialized_end=635
  _LISTSCHEMASRESPONSE._serialized_start=637
  _LISTSCHEMASRESPONSE._serialized_end=721
  _GETSCHEMAREQUEST._serialized_start=724
  _GETSCHEMAREQUEST._serialized_end=914
  _GETSCHEMARESPONSE._serialized_start=917
  _GETSCHEMARESPONSE._serialized_end=1065
  _CREATESCHEMAREQUEST._serialized_start=1068
  _CREATESCHEMAREQUEST._serialized_end=1216
  _CREATESCHEMARESPONSE._serialized_start=1218
  _CREATESCHEMARESPONSE._serialized_end=1334
  _UPDATESCHEMAREQUEST._serialized_start=1337
  _UPDATESCHEMAREQUEST._serialized_end=1594
  _UPDATESCHEMARESPONSE._serialized_start=1596
  _UPDATESCHEMARESPONSE._serialized_end=1712
  _ACTIVATESCHEMAREQUEST._serialized_start=1715
  _ACTIVATESCHEMAREQUEST._serialized_end=1885
  _ACTIVATESCHEMARESPONSE._serialized_start=1887
  _ACTIVATESCHEMARESPONSE._serialized_end=1911
  _DELETESCHEMAREQUEST._serialized_start=1914
  _DELETESCHEMAREQUEST._serialized_end=2082
  _DELETESCHEMARESPONSE._serialized_start=2084
  _DELETESCHEMARESPONSE._serialized_end=2106
  _ARCHIVESCHEMAREQUEST._serialized_start=2109
  _ARCHIVESCHEMAREQUEST._serialized_end=2278
  _ARCHIVESCHEMARESPONSE._serialized_start=2280
  _ARCHIVESCHEMARESPONSE._serialized_end=2303
  _GETSCHEMACODEREQUEST._serialized_start=2306
  _GETSCHEMACODEREQUEST._serialized_end=2449
  _GETSCHEMACODERESPONSE._serialized_start=2451
  _GETSCHEMACODERESPONSE._serialized_end=2551
  _GETSCHEMADEFINITIONREQUEST._serialized_start=2554
  _GETSCHEMADEFINITIONREQUEST._serialized_end=2696
  _GETSCHEMADEFINITIONRESPONSE._serialized_start=2698
  _GETSCHEMADEFINITIONRESPONSE._serialized_end=2759
  _SCHEMASSERVICE._serialized_start=2762
  _SCHEMASSERVICE._serialized_end=3835
# @@protoc_insertion_point(module_scope)
