# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2strmprivacy/api/installations/v1/entities_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xbc\x02\n\x0cInstallation\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12\x64\n\x11installation_type\x18\x02 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\x12\x36\n\x12\x62illing_account_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x10\x62illingAccountId\x12t\n\x18installation_credentials\x18\x04 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstallationCredentialsR\x17installationCredentials\"\x96\x01\n\x17InstallationCredentials\x12 \n\tclient_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12/\n\x11image_pull_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0fimagePullSecret\"\xdb\x01\n\x12InstalledComponent\x12i\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\rcomponentType\x12Z\n\tinstances\x18\x02 \x03(\x0b\x32<.strmprivacy.api.installations.v1.InstalledComponentInstanceR\tinstances\"\x88\x01\n\x1aInstalledComponentInstance\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x03R\x02id\x12Q\n\x06states\x18\x02 \x03(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x06states\"\xf4\x01\n\x1fInstalledComponentsCurrentState\x12i\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\rcomponentType\x12\x66\n\tinstances\x18\x02 \x03(\x0b\x32H.strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentStateR\tinstances\"\x92\x01\n&InstalledComponentInstanceCurrentState\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x04R\x02id\x12O\n\x05state\x18\x02 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x05state\"\xe7\x01\n\x17InstalledComponentState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstateTime\x12\x66\n\nstate_type\x18\x02 \x01(\x0e\x32=.strmprivacy.api.installations.v1.InstalledComponentStateTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\tstateType\x12$\n\x07message\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x04\xd0\x01\x01R\x07message*\x7f\n\x10InstallationType\x12!\n\x1dINSTALLATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x0f\n\x0bSELF_HOSTED\x10\x02\x12\x13\n\x0f\x41WS_MARKETPLACE\x10\x03\x12\x18\n\x14\x41WS_MARKETPLACE_PAYG\x10\x04*\xfb\x01\n\x16InstalledComponentType\x12(\n$INSTALLED_COMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42\x41TCH_JOBS_AGENT\x10\x01\x12\x19\n\x15\x42\x41TCH_EXPORTERS_AGENT\x10\x02\x12\x19\n\x15KAFKA_EXPORTERS_AGENT\x10\x03\x12\x11\n\rSTREAMS_AGENT\x10\x04\x12\x11\n\rEVENT_GATEWAY\x10\x05\x12\x0e\n\nWEB_SOCKET\x10\x06\x12\x19\n\x15\x44\x41TA_CONNECTORS_AGENT\x10\x07\x12\x1a\n\x16\x43ONFLUENT_SCHEMA_PROXY\x10\x08*\x89\x01\n\x1bInstalledComponentStateType\x12.\n*INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x11\n\rSHUTTING_DOWN\x10\x04\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.entities_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _INSTALLATION.fields_by_name['id']._options = None
  _INSTALLATION.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _INSTALLATION.fields_by_name['installation_type']._options = None
  _INSTALLATION.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _INSTALLATION.fields_by_name['billing_account_id']._options = None
  _INSTALLATION.fields_by_name['billing_account_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\003'
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\004'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._serialized_options = b'\372B\007r\005\020\004\320\001\001'
  _INSTALLATIONTYPE._serialized_start=1642
  _INSTALLATIONTYPE._serialized_end=1769
  _INSTALLEDCOMPONENTTYPE._serialized_start=1772
  _INSTALLEDCOMPONENTTYPE._serialized_end=2023
  _INSTALLEDCOMPONENTSTATETYPE._serialized_start=2026
  _INSTALLEDCOMPONENTSTATETYPE._serialized_end=2163
  _INSTALLATION._serialized_start=180
  _INSTALLATION._serialized_end=496
  _INSTALLATIONCREDENTIALS._serialized_start=499
  _INSTALLATIONCREDENTIALS._serialized_end=649
  _INSTALLEDCOMPONENT._serialized_start=652
  _INSTALLEDCOMPONENT._serialized_end=871
  _INSTALLEDCOMPONENTINSTANCE._serialized_start=874
  _INSTALLEDCOMPONENTINSTANCE._serialized_end=1010
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_start=1013
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_end=1257
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_start=1260
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_end=1406
  _INSTALLEDCOMPONENTSTATE._serialized_start=1409
  _INSTALLEDCOMPONENTSTATE._serialized_end=1640
# @@protoc_insertion_point(module_scope)
