# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/streams/v1/streams_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/streams/v1/streams_v1.proto\x12\x1astrmprivacy.api.streams.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x89\x01\n\x12ListStreamsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"X\n\x13ListStreamsResponse\x12\x41\n\x07streams\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.StreamTreeR\x07streams\"E\n\x1aListExtendedStreamsRequest\x12\'\n\nclient_ids\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01R\tclientIds\"u\n\x1bListExtendedStreamsResponse\x12V\n\x10\x65xtended_streams\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStreamR\x0f\x65xtendedStreams\"w\n\x13\x44\x65leteStreamRequest\x12\x42\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"\x16\n\x14\x44\x65leteStreamResponse\"\\\n\x13\x43reateStreamRequest\x12\x45\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06stream\"S\n\x14\x43reateStreamResponse\x12;\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamR\x06stream\"t\n\x10GetStreamRequest\x12\x42\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"]\n\x11GetStreamResponse\x12H\n\x0bstream_tree\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.StreamTreeR\nstreamTree2\xd9\x04\n\x0eStreamsService\x12n\n\x0bListStreams\x12..strmprivacy.api.streams.v1.ListStreamsRequest\x1a/.strmprivacy.api.streams.v1.ListStreamsResponse\x12\x86\x01\n\x13ListExtendedStreams\x12\x36.strmprivacy.api.streams.v1.ListExtendedStreamsRequest\x1a\x37.strmprivacy.api.streams.v1.ListExtendedStreamsResponse\x12h\n\tGetStream\x12,.strmprivacy.api.streams.v1.GetStreamRequest\x1a-.strmprivacy.api.streams.v1.GetStreamResponse\x12q\n\x0c\x44\x65leteStream\x12/.strmprivacy.api.streams.v1.DeleteStreamRequest\x1a\x30.strmprivacy.api.streams.v1.DeleteStreamResponse\x12q\n\x0c\x43reateStream\x12/.strmprivacy.api.streams.v1.CreateStreamRequest\x1a\x30.strmprivacy.api.streams.v1.CreateStreamResponseBf\n\x1dio.strmprivacy.api.streams.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/streams/v1;streamsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.streams.v1.streams_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.streams.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/streams/v1;streams'
  _LISTSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTSTREAMSREQUEST.fields_by_name['project_id']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTEXTENDEDSTREAMSREQUEST.fields_by_name['client_ids']._options = None
  _LISTEXTENDEDSTREAMSREQUEST.fields_by_name['client_ids']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DELETESTREAMREQUEST.fields_by_name['ref']._options = None
  _DELETESTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATESTREAMREQUEST.fields_by_name['stream']._options = None
  _CREATESTREAMREQUEST.fields_by_name['stream']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSTREAMSREQUEST._serialized_start=148
  _LISTSTREAMSREQUEST._serialized_end=285
  _LISTSTREAMSRESPONSE._serialized_start=287
  _LISTSTREAMSRESPONSE._serialized_end=375
  _LISTEXTENDEDSTREAMSREQUEST._serialized_start=377
  _LISTEXTENDEDSTREAMSREQUEST._serialized_end=446
  _LISTEXTENDEDSTREAMSRESPONSE._serialized_start=448
  _LISTEXTENDEDSTREAMSRESPONSE._serialized_end=565
  _DELETESTREAMREQUEST._serialized_start=567
  _DELETESTREAMREQUEST._serialized_end=686
  _DELETESTREAMRESPONSE._serialized_start=688
  _DELETESTREAMRESPONSE._serialized_end=710
  _CREATESTREAMREQUEST._serialized_start=712
  _CREATESTREAMREQUEST._serialized_end=804
  _CREATESTREAMRESPONSE._serialized_start=806
  _CREATESTREAMRESPONSE._serialized_end=889
  _GETSTREAMREQUEST._serialized_start=891
  _GETSTREAMREQUEST._serialized_end=1007
  _GETSTREAMRESPONSE._serialized_start=1009
  _GETSTREAMRESPONSE._serialized_end=1102
  _STREAMSSERVICE._serialized_start=1105
  _STREAMSSERVICE._serialized_end=1706
# @@protoc_insertion_point(module_scope)
