# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_users/v1/kafka_users_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/kafka_users/v1/kafka_users_v1.proto\x12\x1estrmprivacy.api.kafka_users.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"b\n\x15ListKafkaUsersRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"f\n\x16ListKafkaUsersResponse\x12L\n\x0bkafka_users\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x03\xe0\x41\x02R\nkafkaUsers\"_\n\x16\x44\x65leteKafkaUserRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"\x19\n\x17\x44\x65leteKafkaUserResponse\"i\n\x16\x43reateKafkaUserRequest\x12O\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tkafkaUser\"e\n\x17\x43reateKafkaUserResponse\x12J\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x03\xe0\x41\x02R\tkafkaUser\"\\\n\x13GetKafkaUserRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"b\n\x14GetKafkaUserResponse\x12J\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x03\xe0\x41\x02R\tkafkaUser2\x99\x04\n\x11KafkaUsersService\x12\x7f\n\x0eListKafkaUsers\x12\x35.strmprivacy.api.kafka_users.v1.ListKafkaUsersRequest\x1a\x36.strmprivacy.api.kafka_users.v1.ListKafkaUsersResponse\x12y\n\x0cGetKafkaUser\x12\x33.strmprivacy.api.kafka_users.v1.GetKafkaUserRequest\x1a\x34.strmprivacy.api.kafka_users.v1.GetKafkaUserResponse\x12\x82\x01\n\x0f\x44\x65leteKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.DeleteKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.DeleteKafkaUserResponse\x12\x82\x01\n\x0f\x43reateKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.CreateKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.CreateKafkaUserResponseBr\n!io.strmprivacy.api.kafka_users.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_usersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.kafka_users.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_users'
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._options = None
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTKAFKAUSERSRESPONSE.fields_by_name['kafka_users']._options = None
  _LISTKAFKAUSERSRESPONSE.fields_by_name['kafka_users']._serialized_options = b'\340A\002'
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEKAFKAUSERREQUEST.fields_by_name['kafka_user']._options = None
  _CREATEKAFKAUSERREQUEST.fields_by_name['kafka_user']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEKAFKAUSERRESPONSE.fields_by_name['kafka_user']._options = None
  _CREATEKAFKAUSERRESPONSE.fields_by_name['kafka_user']._serialized_options = b'\340A\002'
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKAFKAUSERRESPONSE.fields_by_name['kafka_user']._options = None
  _GETKAFKAUSERRESPONSE.fields_by_name['kafka_user']._serialized_options = b'\340A\002'
  _LISTKAFKAUSERSREQUEST._serialized_start=192
  _LISTKAFKAUSERSREQUEST._serialized_end=290
  _LISTKAFKAUSERSRESPONSE._serialized_start=292
  _LISTKAFKAUSERSRESPONSE._serialized_end=394
  _DELETEKAFKAUSERREQUEST._serialized_start=396
  _DELETEKAFKAUSERREQUEST._serialized_end=491
  _DELETEKAFKAUSERRESPONSE._serialized_start=493
  _DELETEKAFKAUSERRESPONSE._serialized_end=518
  _CREATEKAFKAUSERREQUEST._serialized_start=520
  _CREATEKAFKAUSERREQUEST._serialized_end=625
  _CREATEKAFKAUSERRESPONSE._serialized_start=627
  _CREATEKAFKAUSERRESPONSE._serialized_end=728
  _GETKAFKAUSERREQUEST._serialized_start=730
  _GETKAFKAUSERREQUEST._serialized_end=822
  _GETKAFKAUSERRESPONSE._serialized_start=824
  _GETKAFKAUSERRESPONSE._serialized_end=922
  _KAFKAUSERSSERVICE._serialized_start=925
  _KAFKAUSERSSERVICE._serialized_end=1462
# @@protoc_insertion_point(module_scope)
