# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/organizations/v1/organizations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/organizations/v1/organizations_v1.proto\x12 strmprivacy.api.organizations.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xa8\x01\n\x12InviteUsersRequest\x12\\\n\x0cuser_invites\x18\x01 \x03(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteB\x0b\xfa\x42\x08\x92\x01\x05\x08\x01\x10\xf4\x03R\x0buserInvites\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\"+\n\nUserInvite\x12\x1d\n\x05\x65mail\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02`\x01R\x05\x65mail\"\x94\x02\n\x13InviteUsersResponse\x12!\n\x0cinvite_count\x18\x01 \x01(\x03R\x0binviteCount\x12]\n\x06issues\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.organizations.v1.InviteUsersResponse.UserInviteIssueR\x06issues\x1a{\n\x0fUserInviteIssue\x12N\n\x06invite\x18\x01 \x01(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06invite\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"\x86\x01\n\x16UpdateUserRolesRequest\x12&\n\x06\x65mails\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02`\x01R\x06\x65mails\x12\x44\n\nuser_roles\x18\x02 \x03(\x0e\x32%.strmprivacy.api.entities.v1.UserRoleR\tuserRoles\"\x19\n\x17UpdateUserRolesResponse\" \n\x1eListOrganizationMembersRequest\"w\n\x1fListOrganizationMembersResponse\x12T\n\x14organization_members\x18\x01 \x03(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x13organizationMembers\"/\n\x0eGetUserRequest\x12\x1d\n\x05\x65mail\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02`\x01R\x05\x65mail\"H\n\x0fGetUserResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x04user2\xac\x04\n\x14OrganizationsService\x12z\n\x0bInviteUsers\x12\x34.strmprivacy.api.organizations.v1.InviteUsersRequest\x1a\x35.strmprivacy.api.organizations.v1.InviteUsersResponse\x12\x86\x01\n\x0fUpdateUserRoles\x12\x38.strmprivacy.api.organizations.v1.UpdateUserRolesRequest\x1a\x39.strmprivacy.api.organizations.v1.UpdateUserRolesResponse\x12n\n\x07GetUser\x12\x30.strmprivacy.api.organizations.v1.GetUserRequest\x1a\x31.strmprivacy.api.organizations.v1.GetUserResponse\x12\x9e\x01\n\x17ListOrganizationMembers\x12@.strmprivacy.api.organizations.v1.ListOrganizationMembersRequest\x1a\x41.strmprivacy.api.organizations.v1.ListOrganizationMembersResponseBx\n#io.strmprivacy.api.organizations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.organizations.v1.organizations_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.organizations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizations'
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._options = None
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._serialized_options = b'\372B\010\222\001\005\010\001\020\364\003'
  _INVITEUSERSREQUEST.fields_by_name['organization_id']._options = None
  _INVITEUSERSREQUEST.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _USERINVITE.fields_by_name['email']._options = None
  _USERINVITE.fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _INVITEUSERSRESPONSE_USERINVITEISSUE.fields_by_name['invite']._options = None
  _INVITEUSERSRESPONSE_USERINVITEISSUE.fields_by_name['invite']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEUSERROLESREQUEST.fields_by_name['emails']._options = None
  _UPDATEUSERROLESREQUEST.fields_by_name['emails']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002`\001'
  _GETUSERREQUEST.fields_by_name['email']._options = None
  _GETUSERREQUEST.fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _INVITEUSERSREQUEST._serialized_start=166
  _INVITEUSERSREQUEST._serialized_end=334
  _USERINVITE._serialized_start=336
  _USERINVITE._serialized_end=379
  _INVITEUSERSRESPONSE._serialized_start=382
  _INVITEUSERSRESPONSE._serialized_end=658
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_start=535
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_end=658
  _UPDATEUSERROLESREQUEST._serialized_start=661
  _UPDATEUSERROLESREQUEST._serialized_end=795
  _UPDATEUSERROLESRESPONSE._serialized_start=797
  _UPDATEUSERROLESRESPONSE._serialized_end=822
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_start=824
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_end=856
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_start=858
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_end=977
  _GETUSERREQUEST._serialized_start=979
  _GETUSERREQUEST._serialized_end=1026
  _GETUSERRESPONSE._serialized_start=1028
  _GETUSERRESPONSE._serialized_end=1100
  _ORGANIZATIONSSERVICE._serialized_start=1103
  _ORGANIZATIONSSERVICE._serialized_end=1659
# @@protoc_insertion_point(module_scope)
