# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/cli/v1/cli.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n strmprivacy/api/cli/v1/cli.proto\x12\x16strmprivacy.api.cli.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xf5\x01\n\x11GetReleaseRequest\x12\xdf\x01\n\x07version\x18\x01 \x01(\tB\xc4\x01\xfa\x42\xc0\x01r\xbd\x01\x32\xb7\x01^v(0|[1-9]\\d*)\\.(0|[1-9]\\d*)\\.(0|[1-9]\\d*)(?:-((?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\\.(?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\\+([0-9a-zA-Z-]+(?:\\.[0-9a-zA-Z-]+)*))?$/gm\xd0\x01\x01R\x07version\"W\n\x12GetReleaseResponse\x12\x41\n\x07release\x18\x01 \x01(\x0b\x32\".strmprivacy.api.cli.v1.CliReleaseB\x03\xe0\x41\x03R\x07release\"\xbd\x01\n\nCliRelease\x12\x1d\n\x07version\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07version\x12\x42\n\x0crelease_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x0breleaseTime\x12\"\n\nsource_uri\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tsourceUri\x12(\n\rrelease_notes\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0creleaseNotes2q\n\nCliService\x12\x63\n\nGetRelease\x12).strmprivacy.api.cli.v1.GetReleaseRequest\x1a*.strmprivacy.api.cli.v1.GetReleaseResponseBZ\n\x19io.strmprivacy.api.cli.v1P\x01Z;github.com/strmprivacy/api-definitions-go/v2/api/cli/v1;clib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.cli.v1.cli_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.strmprivacy.api.cli.v1P\001Z;github.com/strmprivacy/api-definitions-go/v2/api/cli/v1;cli'
  _GETRELEASEREQUEST.fields_by_name['version']._options = None
  _GETRELEASEREQUEST.fields_by_name['version']._serialized_options = b'\372B\300\001r\275\0012\267\001^v(0|[1-9]\\d*)\\.(0|[1-9]\\d*)\\.(0|[1-9]\\d*)(?:-((?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\\.(?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\\+([0-9a-zA-Z-]+(?:\\.[0-9a-zA-Z-]+)*))?$/gm\320\001\001'
  _GETRELEASERESPONSE.fields_by_name['release']._options = None
  _GETRELEASERESPONSE.fields_by_name['release']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['version']._options = None
  _CLIRELEASE.fields_by_name['version']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['release_time']._options = None
  _CLIRELEASE.fields_by_name['release_time']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['source_uri']._options = None
  _CLIRELEASE.fields_by_name['source_uri']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['release_notes']._options = None
  _CLIRELEASE.fields_by_name['release_notes']._serialized_options = b'\340A\003'
  _GETRELEASEREQUEST._serialized_start=152
  _GETRELEASEREQUEST._serialized_end=397
  _GETRELEASERESPONSE._serialized_start=399
  _GETRELEASERESPONSE._serialized_end=486
  _CLIRELEASE._serialized_start=489
  _CLIRELEASE._serialized_end=678
  _CLISERVICE._serialized_start=680
  _CLISERVICE._serialized_end=793
# @@protoc_insertion_point(module_scope)
