# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/sinks/v1/sinks_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/sinks/v1/sinks_v1.proto\x12\x18strmprivacy.api.sinks.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x84\x01\n\x10ListSinksRequest\x12\x1d\n\nbilling_id\x18\x01 \x01(\tR\tbillingId\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials:\x02\x18\x01\"T\n\x11ListSinksResponse\x12;\n\x05sinks\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.SinkTreeR\x05sinks:\x02\x18\x01\"r\n\x11\x44\x65leteSinkRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive:\x02\x18\x01\"\x18\n\x12\x44\x65leteSinkResponse:\x02\x18\x01\"\x84\x01\n\x11\x43reateSinkRequest\x12:\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02R\x04sink\x12/\n\x13include_credentials\x18\x02 \x01(\x08R\x12includeCredentials:\x02\x18\x01\"O\n\x12\x43reateSinkResponse\x12\x35\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkR\x04sink:\x02\x18\x01\"\xa0\x01\n\x0eGetSinkRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials:\x02\x18\x01\"Y\n\x0fGetSinkResponse\x12\x42\n\tsink_tree\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.SinkTreeR\x08sinkTree:\x02\x18\x01\x32\xab\x03\n\x0cSinksService\x12\x64\n\tListSinks\x12*.strmprivacy.api.sinks.v1.ListSinksRequest\x1a+.strmprivacy.api.sinks.v1.ListSinksResponse\x12^\n\x07GetSink\x12(.strmprivacy.api.sinks.v1.GetSinkRequest\x1a).strmprivacy.api.sinks.v1.GetSinkResponse\x12g\n\nDeleteSink\x12+.strmprivacy.api.sinks.v1.DeleteSinkRequest\x1a,.strmprivacy.api.sinks.v1.DeleteSinkResponse\x12g\n\nCreateSink\x12+.strmprivacy.api.sinks.v1.CreateSinkRequest\x1a,.strmprivacy.api.sinks.v1.CreateSinkResponse\x1a\x03\x88\x02\x01\x42`\n\x1bio.strmprivacy.api.sinks.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinksb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.sinks.v1.sinks_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.sinks.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinks'
  _LISTSINKSREQUEST._options = None
  _LISTSINKSREQUEST._serialized_options = b'\030\001'
  _LISTSINKSRESPONSE._options = None
  _LISTSINKSRESPONSE._serialized_options = b'\030\001'
  _DELETESINKREQUEST.fields_by_name['ref']._options = None
  _DELETESINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETESINKREQUEST._options = None
  _DELETESINKREQUEST._serialized_options = b'\030\001'
  _DELETESINKRESPONSE._options = None
  _DELETESINKRESPONSE._serialized_options = b'\030\001'
  _CREATESINKREQUEST.fields_by_name['sink']._options = None
  _CREATESINKREQUEST.fields_by_name['sink']._serialized_options = b'\340A\002'
  _CREATESINKREQUEST._options = None
  _CREATESINKREQUEST._serialized_options = b'\030\001'
  _CREATESINKRESPONSE._options = None
  _CREATESINKRESPONSE._serialized_options = b'\030\001'
  _GETSINKREQUEST.fields_by_name['ref']._options = None
  _GETSINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETSINKREQUEST._options = None
  _GETSINKREQUEST._serialized_options = b'\030\001'
  _GETSINKRESPONSE._options = None
  _GETSINKRESPONSE._serialized_options = b'\030\001'
  _SINKSSERVICE._options = None
  _SINKSSERVICE._serialized_options = b'\210\002\001'
  _LISTSINKSREQUEST._serialized_start=150
  _LISTSINKSREQUEST._serialized_end=282
  _LISTSINKSRESPONSE._serialized_start=284
  _LISTSINKSRESPONSE._serialized_end=368
  _DELETESINKREQUEST._serialized_start=370
  _DELETESINKREQUEST._serialized_end=484
  _DELETESINKRESPONSE._serialized_start=486
  _DELETESINKRESPONSE._serialized_end=510
  _CREATESINKREQUEST._serialized_start=513
  _CREATESINKREQUEST._serialized_end=645
  _CREATESINKRESPONSE._serialized_start=647
  _CREATESINKRESPONSE._serialized_end=726
  _GETSINKREQUEST._serialized_start=729
  _GETSINKREQUEST._serialized_end=889
  _GETSINKRESPONSE._serialized_start=891
  _GETSINKRESPONSE._serialized_end=980
  _SINKSSERVICE._serialized_start=983
  _SINKSSERVICE._serialized_end=1410
# @@protoc_insertion_point(module_scope)
