# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/usage/v1/usage_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/usage/v1/usage_v1.proto\x12\x18strmprivacy.api.usage.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x8b\x02\n\x1aGetStreamEventUsageRequest\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\x03ref\x12\x39\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x41\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08<R\x08interval\"\xa2\x01\n\x1bGetStreamEventUsageResponse\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\x03ref\x12I\n\x07windows\x18\x02 \x03(\x0b\x32/.strmprivacy.api.entities.v1.WindowedEventCountR\x07windows\"\x9c\x02\n\x16StoreUsageEventRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x37\n\x06stream\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x06stream\x12(\n\x0b\x65vent_count\x18\x03 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\neventCount\x12H\n\x12\x65vent_arrival_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ventArrivalTime\x12\'\n\nproject_id\x18\x05 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x19\n\x17StoreUsageEventResponse2\x8b\x02\n\x0cUsageService\x12\x82\x01\n\x13GetStreamEventUsage\x12\x34.strmprivacy.api.usage.v1.GetStreamEventUsageRequest\x1a\x35.strmprivacy.api.usage.v1.GetStreamEventUsageResponse\x12v\n\x0fStoreUsageEvent\x12\x30.strmprivacy.api.usage.v1.StoreUsageEventRequest\x1a\x31.strmprivacy.api.usage.v1.StoreUsageEventResponseB`\n\x1bio.strmprivacy.api.usage.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.usage.v1.usage_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.usage.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usage'
  _GETSTREAMEVENTUSAGEREQUEST.fields_by_name['interval']._options = None
  _GETSTREAMEVENTUSAGEREQUEST.fields_by_name['interval']._serialized_options = b'\372B\007\252\001\0042\002\010<'
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _STOREUSAGEEVENTREQUEST.fields_by_name['stream']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['stream']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _STOREUSAGEEVENTREQUEST.fields_by_name['event_count']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['event_count']._serialized_options = b'\372B\004\032\002(\000'
  _STOREUSAGEEVENTREQUEST.fields_by_name['project_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETSTREAMEVENTUSAGEREQUEST._serialized_start=207
  _GETSTREAMEVENTUSAGEREQUEST._serialized_end=474
  _GETSTREAMEVENTUSAGERESPONSE._serialized_start=477
  _GETSTREAMEVENTUSAGERESPONSE._serialized_end=639
  _STOREUSAGEEVENTREQUEST._serialized_start=642
  _STOREUSAGEEVENTREQUEST._serialized_end=926
  _STOREUSAGEEVENTRESPONSE._serialized_start=928
  _STOREUSAGEEVENTRESPONSE._serialized_end=953
  _USAGESERVICE._serialized_start=956
  _USAGESERVICE._serialized_end=1223
# @@protoc_insertion_point(module_scope)
