# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMstrmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto\x12+strmprivacy.api.customer_entity_versions.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x89\x01\n\x1cGetBatchExporterImageRequest\x12i\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x10installationType\"\x94\x01\n\x1dGetBatchExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x36\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x02\x18\x01R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x1e\n\x1cGetKafkaExporterImageRequest\":\n\x1dGetKafkaExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\"\x85\x01\n\x18GetDecrypterImageRequest\x12i\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x10installationType\"\x90\x01\n\x19GetDecrypterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x36\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x02\x18\x01R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x8a\x01\n\x1dGetBatchJobRunnerImageRequest\x12i\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x10installationType\"\x95\x01\n\x1eGetBatchJobRunnerImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x36\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x02\x18\x01R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag2\xda\x05\n\x1d\x43ustomerEntityVersionsService\x12\xae\x01\n\x15GetBatchExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse\x12\xae\x01\n\x15GetKafkaExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse\x12\xa2\x01\n\x11GetDecrypterImage\x12\x45.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest\x1a\x46.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse\x12\xb1\x01\n\x16GetBatchJobRunnerImage\x12J.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest\x1aK.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponseB\x99\x01\n.io.strmprivacy.api.customer_entity_versions.v1P\x01Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.strmprivacy.api.customer_entity_versions.v1P\001Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versions'
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_start=237
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_end=374
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_start=377
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_end=525
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_start=527
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_end=557
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_start=559
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_end=617
  _GETDECRYPTERIMAGEREQUEST._serialized_start=620
  _GETDECRYPTERIMAGEREQUEST._serialized_end=753
  _GETDECRYPTERIMAGERESPONSE._serialized_start=756
  _GETDECRYPTERIMAGERESPONSE._serialized_end=900
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_start=903
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_end=1041
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_start=1044
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_end=1193
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_start=1196
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_end=1926
# @@protoc_insertion_point(module_scope)
