# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.schemas.v1 import schemas_v1_pb2 as strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2


class SchemasServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSchemas = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/ListSchemas',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasResponse.FromString,
                )
        self.GetSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/GetSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaResponse.FromString,
                )
        self.CreateSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/CreateSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaResponse.FromString,
                )
        self.UpdateSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/UpdateSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaResponse.FromString,
                )
        self.GetSchemaCode = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaCode',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeResponse.FromString,
                )
        self.ActivateSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/ActivateSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaResponse.FromString,
                )
        self.DeleteSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/DeleteSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaResponse.FromString,
                )
        self.ArchiveSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/ArchiveSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaResponse.FromString,
                )
        self.GetSchemaDefinition = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaDefinition',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionResponse.FromString,
                )


class SchemasServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSchemas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchemaCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchemaDefinition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SchemasServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSchemas': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSchemas,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasResponse.SerializeToString,
            ),
            'GetSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaResponse.SerializeToString,
            ),
            'CreateSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaResponse.SerializeToString,
            ),
            'UpdateSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaResponse.SerializeToString,
            ),
            'GetSchemaCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchemaCode,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeResponse.SerializeToString,
            ),
            'ActivateSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaResponse.SerializeToString,
            ),
            'DeleteSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaResponse.SerializeToString,
            ),
            'ArchiveSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaResponse.SerializeToString,
            ),
            'GetSchemaDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchemaDefinition,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.schemas.v1.SchemasService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SchemasService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSchemas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/ListSchemas',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/GetSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/CreateSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/UpdateSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchemaCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaCode',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/ActivateSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/DeleteSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/ArchiveSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchemaDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaDefinition',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
