# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/handles/v1/handles_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/handles/v1/handles_v1.proto\x12\x1astrmprivacy.api.handles.v1\x1a\x17validate/validate.proto\"S\n\x1eListInstallationHandlesRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"T\n\x1fListInstallationHandlesResponse\x12\x31\n\x14installation_handles\x18\x01 \x03(\tR\x13installationHandles2\xa5\x01\n\x0eHandlesService\x12\x92\x01\n\x17ListInstallationHandles\x12:.strmprivacy.api.handles.v1.ListInstallationHandlesRequest\x1a;.strmprivacy.api.handles.v1.ListInstallationHandlesResponseBf\n\x1dio.strmprivacy.api.handles.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/handles/v1;handlesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.handles.v1.handles_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.handles.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/handles/v1;handles'
  _LISTINSTALLATIONHANDLESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLATIONHANDLESREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTINSTALLATIONHANDLESREQUEST._serialized_start=100
  _LISTINSTALLATIONHANDLESREQUEST._serialized_end=183
  _LISTINSTALLATIONHANDLESRESPONSE._serialized_start=185
  _LISTINSTALLATIONHANDLESRESPONSE._serialized_end=269
  _HANDLESSERVICE._serialized_start=272
  _HANDLESSERVICE._serialized_end=437
# @@protoc_insertion_point(module_scope)
