# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/agents/v1/data_connector_agent_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/agents/v1/data_connector_agent_v1.proto\x12\x19strmprivacy.api.agents.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"&\n\x1fGetDesiredDataConnectorsRequest:\x03\xf8\x42\x00\"w\n GetDesiredDataConnectorsResponse\x12S\n\x0f\x64\x61ta_connectors\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorR\x0e\x64\x61taConnectors2\xb2\x01\n\x1a\x44\x61taConnectorsAgentService\x12\x93\x01\n\x18GetDesiredDataConnectors\x12:.strmprivacy.api.agents.v1.GetDesiredDataConnectorsRequest\x1a;.strmprivacy.api.agents.v1.GetDesiredDataConnectorsResponseBc\n\x1cio.strmprivacy.api.agents.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agentsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.agents.v1.data_connector_agent_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.agents.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agents'
  _GETDESIREDDATACONNECTORSREQUEST._options = None
  _GETDESIREDDATACONNECTORSREQUEST._serialized_options = b'\370B\000'
  _GETDESIREDDATACONNECTORSREQUEST._serialized_start=158
  _GETDESIREDDATACONNECTORSREQUEST._serialized_end=196
  _GETDESIREDDATACONNECTORSRESPONSE._serialized_start=198
  _GETDESIREDDATACONNECTORSRESPONSE._serialized_end=317
  _DATACONNECTORSAGENTSERVICE._serialized_start=320
  _DATACONNECTORSAGENTSERVICE._serialized_end=498
# @@protoc_insertion_point(module_scope)
