# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.streams.v1 import streams_v1_pb2 as strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2


class StreamsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListStreams = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/ListStreams',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsResponse.FromString,
                )
        self.ListExtendedStreams = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/ListExtendedStreams',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsResponse.FromString,
                )
        self.GetStream = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/GetStream',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamResponse.FromString,
                )
        self.DeleteStream = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/DeleteStream',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamResponse.FromString,
                )
        self.CreateStream = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/CreateStream',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamResponse.FromString,
                )


class StreamsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListStreams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExtendedStreams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStreams,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsResponse.SerializeToString,
            ),
            'ListExtendedStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExtendedStreams,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsResponse.SerializeToString,
            ),
            'GetStream': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStream,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamResponse.SerializeToString,
            ),
            'DeleteStream': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStream,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamResponse.SerializeToString,
            ),
            'CreateStream': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStream,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.streams.v1.StreamsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/ListStreams',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExtendedStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/ListExtendedStreams',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/GetStream',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/DeleteStream',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/CreateStream',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
