# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_exporters/v1/kafka_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/kafka_exporters/v1/kafka_exporters_v1.proto\x12\"strmprivacy.api.kafka_exporters.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"r\n\x19ListKafkaExportersRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"q\n\x1aListKafkaExportersResponse\x12S\n\x0fkafka_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\x0ekafkaExporters\"\x85\x01\n\x1a\x44\x65leteKafkaExporterRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"\x1d\n\x1b\x44\x65leteKafkaExporterResponse\"y\n\x1a\x43reateKafkaExporterRequest\x12[\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\rkafkaExporter\"p\n\x1b\x43reateKafkaExporterResponse\x12Q\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\rkafkaExporter\"d\n\x17GetKafkaExporterRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"m\n\x18GetKafkaExporterResponse\x12Q\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\rkafkaExporter2\xef\x04\n\x15KafkaExportersService\x12\x93\x01\n\x12ListKafkaExporters\x12=.strmprivacy.api.kafka_exporters.v1.ListKafkaExportersRequest\x1a>.strmprivacy.api.kafka_exporters.v1.ListKafkaExportersResponse\x12\x8d\x01\n\x10GetKafkaExporter\x12;.strmprivacy.api.kafka_exporters.v1.GetKafkaExporterRequest\x1a<.strmprivacy.api.kafka_exporters.v1.GetKafkaExporterResponse\x12\x96\x01\n\x13\x44\x65leteKafkaExporter\x12>.strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterRequest\x1a?.strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterResponse\x12\x96\x01\n\x13\x43reateKafkaExporter\x12>.strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterRequest\x1a?.strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterResponseB~\n%io.strmprivacy.api.kafka_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_exporters/v1;kafka_exportersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.kafka_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_exporters/v1;kafka_exporters'
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEKAFKAEXPORTERREQUEST.fields_by_name['kafka_exporter']._options = None
  _CREATEKAFKAEXPORTERREQUEST.fields_by_name['kafka_exporter']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKAFKAEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTKAFKAEXPORTERSREQUEST._serialized_start=171
  _LISTKAFKAEXPORTERSREQUEST._serialized_end=285
  _LISTKAFKAEXPORTERSRESPONSE._serialized_start=287
  _LISTKAFKAEXPORTERSRESPONSE._serialized_end=400
  _DELETEKAFKAEXPORTERREQUEST._serialized_start=403
  _DELETEKAFKAEXPORTERREQUEST._serialized_end=536
  _DELETEKAFKAEXPORTERRESPONSE._serialized_start=538
  _DELETEKAFKAEXPORTERRESPONSE._serialized_end=567
  _CREATEKAFKAEXPORTERREQUEST._serialized_start=569
  _CREATEKAFKAEXPORTERREQUEST._serialized_end=690
  _CREATEKAFKAEXPORTERRESPONSE._serialized_start=692
  _CREATEKAFKAEXPORTERRESPONSE._serialized_end=804
  _GETKAFKAEXPORTERREQUEST._serialized_start=806
  _GETKAFKAEXPORTERREQUEST._serialized_end=906
  _GETKAFKAEXPORTERRESPONSE._serialized_start=908
  _GETKAFKAEXPORTERRESPONSE._serialized_end=1017
  _KAFKAEXPORTERSSERVICE._serialized_start=1020
  _KAFKAEXPORTERSSERVICE._serialized_end=1643
# @@protoc_insertion_point(module_scope)
