# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/installations/v1/installations_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\x1a\x17validate/validate.proto\"K\n\x16GetInstallationRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"r\n\x17GetInstallationResponse\x12W\n\x0cinstallation\x18\x01 \x01(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02R\x0cinstallation\"\x1a\n\x18ListInstallationsRequest\"v\n\x19ListInstallationsResponse\x12Y\n\rinstallations\x18\x01 \x03(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02R\rinstallations\"G\n\x1dGetProjectInstallationRequest\x12\"\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tprojectId:\x02\x18\x01\"R\n\x1eGetProjectInstallationResponse\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId:\x02\x18\x01\"S\n\x1fListInstallationProjectsRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId:\x02\x18\x01\"G\n ListInstallationProjectsResponse\x12\x1f\n\x0bproject_ids\x18\x01 \x03(\tR\nprojectIds:\x02\x18\x01\x32\xfa\x04\n\x14InstallationsService\x12\x86\x01\n\x0fGetInstallation\x12\x38.strmprivacy.api.installations.v1.GetInstallationRequest\x1a\x39.strmprivacy.api.installations.v1.GetInstallationResponse\x12\x8c\x01\n\x11ListInstallations\x12:.strmprivacy.api.installations.v1.ListInstallationsRequest\x1a;.strmprivacy.api.installations.v1.ListInstallationsResponse\x12\xa0\x01\n\x16GetProjectInstallation\x12?.strmprivacy.api.installations.v1.GetProjectInstallationRequest\x1a@.strmprivacy.api.installations.v1.GetProjectInstallationResponse\"\x03\x88\x02\x01\x12\xa6\x01\n\x18ListInstallationProjects\x12\x41.strmprivacy.api.installations.v1.ListInstallationProjectsRequest\x1a\x42.strmprivacy.api.installations.v1.ListInstallationProjectsResponse\"\x03\x88\x02\x01\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.installations_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._options = None
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._serialized_options = b'\340A\002'
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._options = None
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONREQUEST._options = None
  _GETPROJECTINSTALLATIONREQUEST._serialized_options = b'\030\001'
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._options = None
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONRESPONSE._options = None
  _GETPROJECTINSTALLATIONRESPONSE._serialized_options = b'\030\001'
  _LISTINSTALLATIONPROJECTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLATIONPROJECTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _LISTINSTALLATIONPROJECTSREQUEST._options = None
  _LISTINSTALLATIONPROJECTSREQUEST._serialized_options = b'\030\001'
  _LISTINSTALLATIONPROJECTSRESPONSE._options = None
  _LISTINSTALLATIONPROJECTSRESPONSE._serialized_options = b'\030\001'
  _INSTALLATIONSSERVICE.methods_by_name['GetProjectInstallation']._options = None
  _INSTALLATIONSSERVICE.methods_by_name['GetProjectInstallation']._serialized_options = b'\210\002\001'
  _INSTALLATIONSSERVICE.methods_by_name['ListInstallationProjects']._options = None
  _INSTALLATIONSSERVICE.methods_by_name['ListInstallationProjects']._serialized_options = b'\210\002\001'
  _GETINSTALLATIONREQUEST._serialized_start=203
  _GETINSTALLATIONREQUEST._serialized_end=278
  _GETINSTALLATIONRESPONSE._serialized_start=280
  _GETINSTALLATIONRESPONSE._serialized_end=394
  _LISTINSTALLATIONSREQUEST._serialized_start=396
  _LISTINSTALLATIONSREQUEST._serialized_end=422
  _LISTINSTALLATIONSRESPONSE._serialized_start=424
  _LISTINSTALLATIONSRESPONSE._serialized_end=542
  _GETPROJECTINSTALLATIONREQUEST._serialized_start=544
  _GETPROJECTINSTALLATIONREQUEST._serialized_end=615
  _GETPROJECTINSTALLATIONRESPONSE._serialized_start=617
  _GETPROJECTINSTALLATIONRESPONSE._serialized_end=699
  _LISTINSTALLATIONPROJECTSREQUEST._serialized_start=701
  _LISTINSTALLATIONPROJECTSREQUEST._serialized_end=784
  _LISTINSTALLATIONPROJECTSRESPONSE._serialized_start=786
  _LISTINSTALLATIONPROJECTSRESPONSE._serialized_end=857
  _INSTALLATIONSSERVICE._serialized_start=860
  _INSTALLATIONSSERVICE._serialized_end=1494
# @@protoc_insertion_point(module_scope)
