# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_connectors.v1 import data_connectors_v1_pb2 as strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2


class DataConnectorsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataConnectors = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/ListDataConnectors',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsResponse.FromString,
                )
        self.GetDataConnector = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/GetDataConnector',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorResponse.FromString,
                )
        self.DeleteDataConnector = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/DeleteDataConnector',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorResponse.FromString,
                )
        self.CreateDataConnector = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/CreateDataConnector',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorResponse.FromString,
                )


class DataConnectorsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataConnectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataConnectorsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataConnectors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataConnectors,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsResponse.SerializeToString,
            ),
            'GetDataConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataConnector,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorResponse.SerializeToString,
            ),
            'DeleteDataConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataConnector,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorResponse.SerializeToString,
            ),
            'CreateDataConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataConnector,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_connectors.v1.DataConnectorsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataConnectorsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataConnectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/ListDataConnectors',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/GetDataConnector',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/DeleteDataConnector',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/CreateDataConnector',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
